@@ -40,9 +40,10 @@ class Act(object):
     def __init__(self, frame=None, context=None, act=None, actor=None,
                  registrar=None, inits=None, ioinits=None, parms=None,
                  prerefs=None, human='', count=0, **kwa ):
-        """ Initialization method for instance.
+        """
+        Initialization method for instance.
 
-            Attributes:
+        Attributes:
             .frame = ref to Frame holding this Act
             .context = name string of actioning context set when added to frame
             .act = ref to super Act if self is embedded in another Act such as Need
@@ -55,6 +56,13 @@ class Act(object):
             .prerefs = dictionary of init, ioinit, and parm refs to resolve
             .human = human friendly version of action declaration
             .count = line count in floscript of action declaration
+
+        Share path resolution
+            act.resolve aggregates ioinits from registry,  act.ioinits, and act.prerefs
+            act.resolve calls .actor._initio with ionits as parameters to get iois
+            then for each ioi act.resolve calls .resolvePath to get share or node
+            and then assigns share/node to to attribute/parameter of .actor
+
         """
         super(Act,self).__init__(**kwa) # in case of MRO
 
@@ -146,16 +154,16 @@ class Act(object):
                         if field in src:  # only update if src has field
                             parms[field] = src[field]
 
-            ioinits.update(self.ioinits or odict())
-            if self.prerefs: # preinits ioinits dict items
+            ioinits.update(self.ioinits or odict())  # self.ioinits 'do per'
+            if self.prerefs: # preinits ioinits dict items  'do for'
                 # each key is share src path, and value is list of src fields
                 for src, fields in self.prerefs.get('ioinits', {}).items():
                     src = self.resolvePath(ipath=src, warn=True) # now a share
                     if not fields:  # default is use existing fields
                         fields = self._prepareSrcFields(src, fields)
-                    for field in fields:  # requires src pre inited
+                    for field in fields:  # each src fld value pre inited with ipath
                         if field in src:  # only update if src has field
-                            ioinits[field] = src[field]
+                            ioinits[field] = src[field]  # clobbers ioinit odict() with ipath
             if ioinits:
                 iois = actor._initio(**ioinits)
                 if iois:
@@ -186,35 +194,38 @@ class Act(object):
             self.actor._prepare(**self.parms)
 
     def resolvePath(self, ipath, ival=None, iown=None, warn=False):
-        """ Returns resolved Share or Node instance from ipath
-            ipath may be path name of share or node
-            or reference to Share or Node instance
+        """
+        Returns resolved Share or Node instance from ipath
+        ipath may be path name of share or node
+        or reference to Share or Node instance
 
-            This method resolves pathname strings into share and node references
-            at resolve time.
+        This method resolves inline pathname strings into share and node references
+        at resolve time.
 
-            ival is optional value for share
-            iown is optional ownership if True then overwrite if exists
-                   otherwise do not overwrite
+        ival is optional value for share
+        iown is optional ownership if True then overwrite if exists
+               otherwise do not overwrite
 
-            if warn then will complain if the share is created.
+        if warn then will complain if the share is created.
 
-            It allows for substitution into ipath of
-            frame, framer, actor, main frame, or main framer relative names.
-            So that lexically relative pathnames can
-            be dynamically resolved in support of framer cloning.
-            It assumes that any implied variants have been reconciled.
-            If .actor is not yet instantiated then raises exception if ipath
-               uses actor relative addressing. This may occur for init prerefs.
+        It allows for substitution into ipath of
+        inode, framer,  main framer, frame, main frame, or actor relative names.
+        So that lexically relative pathnames can
+        be dynamically resolved in support of framer cloning.
+        It assumes that any implied variants have been reconciled.
+        If .actor is not yet instantiated then raises exception if ipath
+           uses actor relative addressing. This may occur for init prerefs.
 
-            When ipath is a string:  (not a Node or Share reference)
-                the following syntax is used:
+        When ipath is a string:  (not a Node or Share reference)
+            the following syntax is used:
 
-                If the path name starts with a leading '.' dot then path name is
-                fully reconciled and no contextual substitutions are to be applied.
+            If the path name starts with a leading '.' dot then path name is
+            fully reconciled and no contextual substitutions are to be applied.
 
-                Otherwise make subsitutions in pathname strings that begin
-                with 'framer.'
+            If the path name begins with 'me' then the path is framer inode relative
+
+            Otherwise make subsitutions in pathname strings that begin
+            with 'framer.'
                 Substitute for special path part 'framer' with names of 'me' or 'main'
                 Substitute for special path part 'frame' with names  of 'me' or 'main'
                 Substitute for special path part 'actor' with name of 'me'
@@ -225,28 +236,33 @@ class Act(object):
                 'main' indicates substitute the current frame's main framer or main frame
                 name respectively obtained from
 
-            When  ipath is a pathname string that resolves to a Share and ival is not None
-            Then ival is used to initialize the share values.
-                ival should be a share initializer:
-                   valid initializers are:
-                       a dict of fields and values
-                       a list of duples, each a (key, value) item
 
-                If own is True then .update(ival) is used
-                Otherwise .create(ival) is used
 
-            Requires that:
-               self.store exist
+        If ipath ends with a '.' then it resolves to a node
+        Otherwise if not trailing dot it resolves to a share
 
-               The following have already been resolved:
-                   self.frame
-                   self.frame.framer
-                   self.frame.framer.main
-                   self.frame.framer.main.framer
+        When  ipath is a pathname string that resolves to a Share and ival is not None
+        Then ival is used to initialize the share values.
+            ival should be a share initializer:
+               valid initializers are:
+                   a dict of fields and values
+                   a list of duples, each a (key, value) item
 
-               If actor relative addressing is used then:
-                  self.actor is resolved
-                  self.actor.name is not empty
+            If own is True then .update(ival) is used
+            Otherwise .create(ival) is used
+
+        Requires that:
+           self.store exist
+
+           The following have already been resolved:
+               self.frame
+               self.frame.framer
+               self.frame.framer.main
+               self.frame.framer.main.framer
+
+           If actor relative addressing is used then:
+              self.actor is resolved
+              self.actor.name is not empty
 
         """
         if not (isinstance(ipath, storing.Share) or isinstance(ipath, storing.Node)): # must be pathname
@@ -267,8 +283,12 @@ class Act(object):
                     framer = self.frame.framer
                     finode = framer.inode
                     if framer.main:  # aux framer so special meaning of main or mine
+                        mainer = framer.main.framer  # main frame's framer eg main framer
                         if finode == "main":  # replace finode with main framer inode
-                            finode = framer.main.framer.inode
+                            finode = mainer.inode
+                            while finode == "main" and mainer.main:  # inode is main and has a main frame
+                                mainer = mainer.main.framer # walk up mainer links
+                                finode = mainer.inode  # substitude main for mainer.inode
                         elif finode == "mine":  # don't prepend main framer inode
                             finode = ""
                         else:  # possibly prepend main framer inode if finode relative
@@ -277,6 +297,8 @@ class Act(object):
                             if not finode.startswith('.') and minode:  # prepend if relative
                                 finode = '.'.join([minode, finode])
                     finode = finode.rstrip('.')
+                    if not finode:  # empty finode so use default actor relative
+                        finode = "framer.me.frame.me.actor.me"
                     if finode:
                         finparts = finode.split('.')
                         if finparts:
@@ -469,7 +491,7 @@ def actify(name, base=None, registry=None, inits=None, ioinits=None, parms=None,
     if registry:
         attrs['Registry'] = odict()
     if parametric is not None:
-        attrs['_Parametric'] = parametric
+        attrs['_Parametric'] = True if parametric else False
     if inits:
         attrs['Inits'] = odict(inits)
     if ioinits:
@@ -547,93 +569,114 @@ class Actor(object):
         return parms
 
     def _initio(self, inode='', **kwa):
-        """ Intialize and hookup ioflo shares from node pathname inode and kwa arguments.
-            This implements a generic Actor interface protocol for associating the
-            io data flow shares to the Actor.
+        """
+        Compute initializations for ioflo shares from inode and kwa arguments.
+        This implements a generic Actor interface protocol for associating the
+        io data flow shares to the Actor.
 
-            inode is the computed pathname string of the default share node
-            where shares associated with the Actor instance may be placed when
-            relative addressing is used.
+        inode is the computed pathname string of the default share node
+        where shares associated with the Actor instance may be placed when
+        relative addressing is used.
 
-            The values of the items in the **kwa argument may be either strings or
-            mappings
+        The inode is computed as absolute, relative, or default.
+        The default inode is  'framer.me.frame.me.actor.me.'
+            This occurs if the framer inode (finode) is empty
+                (which occurs when the via clause is missing for the framer)
+            and the ioinit inode parameter passed in is also empty
 
-            For each key,val in **kwa.items() there are the following 2 forms for val:
+        When a via clause exists for the framer then finode is not empty
+            so the default is not used
+            and the computed inode is either absolute or relative
 
-            1- string:
-               ipath = pathnamestring
-            2- dict of items (mapping) of form:
-                {
-                    ipath: "pathnamestring", (optional)
-                    ival: initial value, (optional)
-                    iown: truthy, (optional)
-                }
+        When the inode parameter is relative (no leading dot)
+            it is relative to the framer inode
 
-            In either case, three init values are produced, these are:
-                ipath, ival, iown,
-            Missing init values from ipath, ival, iown will be assigned a
-            default value as per the rules below:
+        If the framer is a cloned auxiliary then the inode could be relative
+            to the main framer inode
 
-            For each kwa item (key, val)
-                key is the name of the associated instance attribute or action parm.
-                Extract ipath, ival, iown from val
+        The values of the items in the **kwa argument may be either strings or
+        mappings
 
-                Shares are initialized with mappings passed into share.create or
-                share.update. So to assign ival to share.value pass into share.create
-                or share.update a mapping of the form {'value': ival} whereas
-                passing in an empty mapping does nothing.
+        For each key,val in **kwa.items() there are the following 2 forms for val:
 
-                If ipath not provided
-                    ipath is the default path inode.key
-                Else ipath is provided
-                    If ipath starts with dot "." Then absolute path
-                    Else ipath does not start with dot "." Then relative path from inode
+        1- string:
+           ipath = pathnamestring
+        2- dict of items (mapping) of form:
+            {
+                ipath: "pathnamestring", (optional)
+                ival: initial value, (optional)
+                iown: truthy, (optional)
+            }
 
-                    If ipath ends with dot Then the path is to a node not share
-                            node ref is created and remaining init values are ignored
+        In either case, three init values are produced, these are:
+            ipath, ival, iown,
+        Missing init values from ipath, ival, iown will be assigned a
+        default value as per the rules below:
+
+        For each kwa item (key, val)
+            key is the name of the associated instance attribute or action parm.
+            Extract ipath, ival, iown from val
+
+            Shares are initialized with mappings passed into share.create or
+            share.update. So to assign ival to share.value pass into share.create
+            or share.update a mapping of the form {'value': ival} whereas
+            passing in an empty mapping does nothing.
+
+            If ipath not provided
+                ipath is the default path inode.key
+            Else ipath is provided
+                If ipath starts with dot "." Then absolute path
+                Else ipath does not start with dot "." Then relative path from inode
+
+                If ipath ends with dot Then the path is to a node not share
+                        node ref is created and remaining init values are ignored
 
 
-                If ival not provided
-                     set ival to empty mapping which when passed to share.create
-                     will not change share.value
-                Else ival provided
-                    If ival is an empty Mapping Then
-                        assign a shallow copy of ival to share.value by passing
-                        in {value: ival (copy)} to share.create/.update
-                    Else If ival is a non-string iterable and not a mapping
-                        assign a shallow copy of ival to share.value by passing
-                        in {value: ival (copy)} to share.create/.update
-                    Else If ival is a non-empty Mapping Then
-                        Each item in ival is assigned as a field, value pair in the share
-                        by passing ival directly into share.create or share.update
-                        This means there is no way to init a share.value to a non empty mapping
-                        It is possible to init a share.value to an empty mapping see below
-                    Else
-                        assign ival to share.value by by passing
-                        in {value: ival} to share.create or share.update
-
-                Create share with pathname given by ipath
-
-                If iown Then
-                    init share with ival value using update
+            If ival not provided
+                 set ival to empty mapping which when passed to share.create
+                 will not change share.value
+            Else ival provided
+                If ival is an empty Mapping Then
+                    assign a shallow copy of ival to share.value by passing
+                    in {value: ival (copy)} to share.create/.update
+                Else If ival is a non-string iterable and not a mapping
+                    assign a shallow copy of ival to share.value by passing
+                    in {value: ival (copy)} to share.create/.update
+                Else If ival is a non-empty Mapping Then
+                    Each item in ival is assigned as a field, value pair in the share
+                    by passing ival directly into share.create or share.update
+                    This means there is no way to init a share.value to a non empty mapping
+                    It is possible to init a share.value to an empty mapping see below
                 Else
-                    init share with ival value using create ((change if not exist))
+                    assign ival to share.value by by passing
+                    in {value: ival} to share.create or share.update
+
+            Create share with pathname given by ipath
+
+            If iown Then
+                init share with ival value using update
+            Else
+                init share with ival value using create ((change if not exist))
 
         """
         if not isinstance(inode, basestring):
             raise ValueError("Nonstring inode arg '{0}'".format(inode))
 
         finode = ''  # inode of framer
-        if self._act.frame.framer:
+        if self._act.frame.framer: # framer has been assigned
             framer = self._act.frame.framer
-            finode = framer.inode
+            finode = framer.inode  # could be empty
             if framer.main:  # aux framer so special meaning of main or mine
+                mainer = framer.main.framer  # main frame's framer eg main framer
                 if finode == "main":  # replace finode with main framer inode
-                    finode = framer.main.framer.inode
+                    finode = mainer.inode
+                    while finode == "main" and mainer.main:  # inode is main and has a main frame
+                        mainer = mainer.main.framer # walk up mainer links
+                        finode = mainer.inode  # substitude main for mainer.inode
                 elif finode == "mine":  # don't prepend main framer inode
-                    finode = ""
-                else:  # possibly prepend main framer inode if finode relative
-                    minode = framer.main.framer.inode
+                    finode = ""  # effectively empty inode
+                else:  # otherwise just prepend main framer inode if relative
+                    minode = framer.main.framer.inode  # could be empty
                     minode = minode.rstrip('.')
                     if not finode.startswith('.') and minode:  # prepend if relative
                         finode = '.'.join([minode, finode])
@@ -641,6 +684,8 @@ class Actor(object):
         finode = finode.rstrip('.')
 
         if not inode.startswith('.') and finode:  # not absolute and finode so prepend
+            if inode.startswith('me.') or inode == 'me':
+                raise ValueError("Invalid inode '{0}', first part == 'me'".format(inode))
             inode = ".".join([finode, inode])
 
         if not inode:  # empty or missing use default actor relative
@@ -651,16 +696,17 @@ class Actor(object):
 
         iois = odict()
 
-        for key, val in kwa.items():
-            if val is None:
-                continue
+        for key, val in kwa.items():  # assumes keys are basestrings
+            if val is None:  # use default assume no way to be inadvertent
+                val = ""  # empty string for val defaults ipath to same as key
+                #continue
 
             if isinstance(val, basestring):
                 ipath = val
                 iown = None
                 ival = odict() # effectively will not change share
             elif isinstance(val, Mapping): # dictionary
-                ipath = val.get('ipath')
+                ipath = val.get('ipath', '')
                 iown = val.get('iown')
 
                 if not 'ival' in val:
@@ -680,17 +726,20 @@ class Actor(object):
 
             if ipath:
                 if not ipath.startswith('.'): # full path is inode joined to ipath
-                    ipath = '.'.join((inode.rstrip('.'), ipath)) # when inode empty prepends dot
-            else:
+                    if not(ipath.startswith('me.') or ipath == 'me'):  # do not override inode
+                        ipath = '.'.join((inode.rstrip('.'), ipath)) # when inode empty prepends dot
+                    # any paths starting with me with have the framer inode (finode) substituted
+                    # in actor.resolvePath later this allows override of doer inode appendix
+            else: # empty ipath
                 ipath = '.'.join((inode.rstrip('.'), key))  # when ipath empty create default from key
 
-            if ipath.startswith('me.') or ipath == 'me':
-                raise ValueError("Invalid ipath '{0}', first part == 'me'".format(ipath))
+            #if ipath.startswith('me.') or ipath == 'me':
+            #    raise ValueError("Invalid ipath '{0}', first part == 'me'".format(ipath))
 
             ioi = odict(ipath=ipath, ival=ival, iown=iown)
             iois[key] = ioi
 
-        ioi = odict(ipath=inode)
+        ioi = odict(ipath=inode)  # create ioi for the inode
         iois['inode'] = ioi
 
         return iois # non-empty when _parametric
@@ -953,11 +1002,11 @@ class Transiter(Interrupter):
         exits, enters, reexens = framing.Framer.ExEn(framer.actives, far)
 
         #check enters, if successful, perform transition
-        if not framer.checkEnter(enters):
+        if not framer.checkEnter(enters, exits):
             return None
 
         msg = "To: {0}<{1} at {2} Via: {3} ({4}) From: {5} after {6:0.3f}\n".format(
-            framer.name, far.human, framer.store.stamp, near.name, human,
+            framer.name, far.human, round(framer.store.stamp, 6), near.name, human,
             framer.human, framer.elapsed)
         console.terse(msg)
 
@@ -1050,15 +1099,15 @@ class Suspender(Interrupter):
             # if aux.main is not None then it has not been released and so
             # we can't enter unless it is our act's frame
             if aux.main and (aux.main is not self._act.frame):
-                console.concise("    Invalid aux '{0}' in use "
-                        "by another frame '{1}'\n".format(aux.name, aux.main.name))
+                console.concise("    Invalid aux '{0}' in use by another frame"
+                        " '{1}'\n".format(aux.name, aux.main.name))
                 return None
 
             if not aux.checkStart(): #performs entry checks
                 return None
 
             msg = "To: {0} in {1}<{2} at {3} Via: {4} ({5}) From: {6} after {7:0.3f}\n".format(
-                aux.name, framer.name, main.headHuman, framer.store.stamp, main.name,
+                aux.name, framer.name, main.headHuman, round(framer.store.stamp, 6), main.name,
                 human, framer.human, framer.elapsed)
             console.terse(msg)
 
