@@ -118,12 +118,16 @@ class NeedDone(Need):
                 result = any([aux.done for aux in frame.auxes ])
             elif tasker == 'all':
                 result = frame.auxes and all([aux.done for aux in frame.auxes])
+            elif tasker in frame.auxes:
+                result = tasker.done
             else:
                 result = False
+            name = tasker if tasker in ('any', 'all') else tasker.name
+            console.profuse("Need Aux {0} done = {1}\n".format(name, result))
 
         else:
             result = tasker.done
-            console.profuse("Need Framer {0} done = {1}\n".format(tasker.name, result))
+            console.profuse("Need Tasker {0} done = {1}\n".format(tasker.name, result))
 
         return result
 
@@ -377,9 +381,10 @@ class NeedMarker(Need):
 
 class NeedUpdate(NeedMarker):
     """ NeedUpdate Need Special Need """
-    def action(self, share, frame, **kw):
+    def action(self, share, frame, aft=False, **kw):
         """
-        Check if share updated while in frame/mark denoted by name key if any
+        Check if share updated since mark in share was updated by marker in
+        frame upon frame entry.
             Default is False
 
         parameters:
@@ -390,10 +395,19 @@ class NeedUpdate(NeedMarker):
         result = False
         mark = share.marks.get(frame.name) #get mark from mark frame name key
         if mark and mark.stamp is not None and share.stamp is not None:
-            result = share.stamp >= mark.stamp #equals so catch updates on enter
+            if aft:
+                result = share.stamp > mark.stamp  # > only catches updates after enter
+            else:
+                result = share.stamp >= mark.stamp  # >= catches updates on same enter
 
-        console.profuse("Need Share {0} update in Frame {1} = {2}\n".format(
-            share.name, frame.name, result))
+        console.profuse("Marker update {0} in Frame {1} of Share {2} {3} "
+                        " {4} mark {5} at {6}\n".format(result,
+                                                     frame.name,
+                                                     share.name,
+                                                     share.stamp,
+                                                     ">" if aft else '>=',
+                                                     mark.stamp,
+                                                     self.store.stamp))
 
         return result
 
